# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.agent_metadata_response import AgentMetadataResponse
from arthur_client.api_bindings.models.metric_response import MetricResponse
from arthur_client.api_bindings.models.rule_response import RuleResponse
from typing import Optional, Set
from typing_extensions import Self

class TaskResponse(BaseModel):
    """
    TaskResponse
    """ # noqa: E501
    id: StrictStr = Field(description=" ID of the task")
    name: StrictStr = Field(description="Name of the task")
    created_at: StrictInt = Field(description="Time the task was created in unix milliseconds")
    updated_at: StrictInt = Field(description="Time the task was created in unix milliseconds")
    is_agentic: Optional[StrictBool] = None
    is_system_task: Optional[StrictBool] = None
    is_autocreated: Optional[StrictBool] = None
    agent_metadata: Optional[AgentMetadataResponse] = None
    rules: List[RuleResponse] = Field(description="List of all the rules for the task.")
    metrics: Optional[List[MetricResponse]] = None
    __properties: ClassVar[List[str]] = ["id", "name", "created_at", "updated_at", "is_agentic", "is_system_task", "is_autocreated", "agent_metadata", "rules", "metrics"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaskResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of agent_metadata
        if self.agent_metadata:
            _dict['agent_metadata'] = self.agent_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in rules (list)
        _items = []
        if self.rules:
            for _item_rules in self.rules:
                if _item_rules:
                    _items.append(_item_rules.to_dict())
            _dict['rules'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in metrics (list)
        _items = []
        if self.metrics:
            for _item_metrics in self.metrics:
                if _item_metrics:
                    _items.append(_item_metrics.to_dict())
            _dict['metrics'] = _items
        # set to None if is_agentic (nullable) is None
        # and model_fields_set contains the field
        if self.is_agentic is None and "is_agentic" in self.model_fields_set:
            _dict['is_agentic'] = None

        # set to None if is_system_task (nullable) is None
        # and model_fields_set contains the field
        if self.is_system_task is None and "is_system_task" in self.model_fields_set:
            _dict['is_system_task'] = None

        # set to None if is_autocreated (nullable) is None
        # and model_fields_set contains the field
        if self.is_autocreated is None and "is_autocreated" in self.model_fields_set:
            _dict['is_autocreated'] = None

        # set to None if agent_metadata (nullable) is None
        # and model_fields_set contains the field
        if self.agent_metadata is None and "agent_metadata" in self.model_fields_set:
            _dict['agent_metadata'] = None

        # set to None if metrics (nullable) is None
        # and model_fields_set contains the field
        if self.metrics is None and "metrics" in self.model_fields_set:
            _dict['metrics'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaskResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "is_agentic": obj.get("is_agentic"),
            "is_system_task": obj.get("is_system_task"),
            "is_autocreated": obj.get("is_autocreated"),
            "agent_metadata": AgentMetadataResponse.from_dict(obj["agent_metadata"]) if obj.get("agent_metadata") is not None else None,
            "rules": [RuleResponse.from_dict(_item) for _item in obj["rules"]] if obj.get("rules") is not None else None,
            "metrics": [MetricResponse.from_dict(_item) for _item in obj["metrics"]] if obj.get("metrics") is not None else None
        })
        return _obj


