# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.data_planes_v1_api import DataPlanesV1Api


class TestDataPlanesV1Api(unittest.TestCase):
    """DataPlanesV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = DataPlanesV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_data_plane(self) -> None:
        """Test case for delete_data_plane

        Delete Data Plane By Id
        """
        pass

    def test_get_data_plane(self) -> None:
        """Test case for get_data_plane

        Get Data Plane By Id
        """
        pass

    def test_get_data_planes(self) -> None:
        """Test case for get_data_planes

        Get Data Planes.
        """
        pass

    def test_get_infrastructures(self) -> None:
        """Test case for get_infrastructures

        Get Supported Infrastructure Values
        """
        pass

    def test_patch_data_plane(self) -> None:
        """Test case for patch_data_plane

        Update Data Plane
        """
        pass

    def test_post_data_plane(self) -> None:
        """Test case for post_data_plane

        Post Data Plane.
        """
        pass

    def test_post_data_plane_cred_set(self) -> None:
        """Test case for post_data_plane_cred_set

        Regenerate Data Plane Credential Set.
        """
        pass


if __name__ == '__main__':
    unittest.main()
