# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.unregistered_agents_v1_api import UnregisteredAgentsV1Api


class TestUnregisteredAgentsV1Api(unittest.TestCase):
    """UnregisteredAgentsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = UnregisteredAgentsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_unregistered_agent(self) -> None:
        """Test case for delete_unregistered_agent

        Delete Unregistered Agent.
        """
        pass

    def test_get_unregistered_agent(self) -> None:
        """Test case for get_unregistered_agent

        Get Unregistered Agent.
        """
        pass

    def test_get_unregistered_agents(self) -> None:
        """Test case for get_unregistered_agents

        Get Unregistered Agents.
        """
        pass

    def test_patch_unregistered_agent(self) -> None:
        """Test case for patch_unregistered_agent

        Patch Unregistered Agent.
        """
        pass

    def test_put_unregistered_agents(self) -> None:
        """Test case for put_unregistered_agents

        Put Unregistered Agents.
        """
        pass


if __name__ == '__main__':
    unittest.main()
