# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.put_task_state_cache_request import PutTaskStateCacheRequest

class TestPutTaskStateCacheRequest(unittest.TestCase):
    """PutTaskStateCacheRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PutTaskStateCacheRequest:
        """Test PutTaskStateCacheRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PutTaskStateCacheRequest`
        """
        model = PutTaskStateCacheRequest()
        if include_optional:
            return PutTaskStateCacheRequest(
                task = arthur_client.api_bindings.models.task_response.TaskResponse(
                    id = '', 
                    name = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    is_agentic = True, 
                    is_system_task = True, 
                    is_autocreated = True, 
                    agent_metadata = arthur_client.api_bindings.models.agent_metadata_response.AgentMetadataResponse(
                        provider = 'gcp', 
                        gcp_metadata = arthur_client.api_bindings.models.gcp_agent_metadata_response.GCPAgentMetadataResponse(
                            project_id = '', 
                            region = '', 
                            resource_id = '', ), ), 
                    rules = [
                        arthur_client.api_bindings.models.rule_response.RuleResponse(
                            id = '', 
                            name = '', 
                            type = 'KeywordRule', 
                            apply_to_prompt = True, 
                            apply_to_response = True, 
                            enabled = True, 
                            scope = 'default', 
                            created_at = 56, 
                            updated_at = 56, 
                            config = null, )
                        ], 
                    metrics = [
                        arthur_client.api_bindings.models.metric_response.MetricResponse(
                            id = '', 
                            name = '', 
                            type = 'QueryRelevance', 
                            metric_metadata = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            enabled = True, )
                        ], ),
                evals = [
                    arthur_client.api_bindings.models.llm_eval.LLMEval(
                        name = '', 
                        model_name = '', 
                        model_provider = 'anthropic', 
                        instructions = '', 
                        variables = [
                            ''
                            ], 
                        tags = [
                            ''
                            ], 
                        config = arthur_client.api_bindings.models.llm_base_config_settings.LLMBaseConfigSettings(
                            timeout = 1.337, 
                            temperature = 1.337, 
                            top_p = 1.337, 
                            max_tokens = 56, 
                            stop = '', 
                            presence_penalty = 1.337, 
                            frequency_penalty = 1.337, 
                            seed = 56, 
                            logprobs = True, 
                            top_logprobs = 56, 
                            logit_bias = [
                                arthur_client.api_bindings.models.logit_bias_item.LogitBiasItem(
                                    token_id = 56, 
                                    bias = -100.0, )
                                ], 
                            max_completion_tokens = 56, 
                            reasoning_effort = 'none', 
                            thinking = arthur_client.api_bindings.models.anthropic_thinking_param.AnthropicThinkingParam(
                                type = 'enabled', 
                                budget_tokens = 56, ), ), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        deleted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        version = 56, )
                    ],
                continuous_evals = [
                    arthur_client.api_bindings.models.continuous_eval_response.ContinuousEvalResponse(
                        id = '', 
                        name = '', 
                        description = '', 
                        task_id = '', 
                        llm_eval_name = '', 
                        llm_eval_version = 56, 
                        transform_id = '', 
                        transform_variable_mapping = [
                            arthur_client.api_bindings.models.continuous_eval_transform_variable_mapping_response.ContinuousEvalTransformVariableMappingResponse(
                                transform_variable = '', 
                                eval_variable = '', )
                            ], 
                        enabled = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                transforms = [
                    arthur_client.api_bindings.models.trace_transform_response.TraceTransformResponse(
                        id = '', 
                        task_id = '', 
                        name = '', 
                        description = '', 
                        definition = arthur_client.api_bindings.models.trace_transform_definition.TraceTransformDefinition(
                            variables = [
                                arthur_client.api_bindings.models.trace_transform_variable_definition.TraceTransformVariableDefinition(
                                    variable_name = '', 
                                    span_name = '', 
                                    attribute_path = '', 
                                    fallback = '', )
                                ], ), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PutTaskStateCacheRequest(
                task = arthur_client.api_bindings.models.task_response.TaskResponse(
                    id = '', 
                    name = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    is_agentic = True, 
                    is_system_task = True, 
                    is_autocreated = True, 
                    agent_metadata = arthur_client.api_bindings.models.agent_metadata_response.AgentMetadataResponse(
                        provider = 'gcp', 
                        gcp_metadata = arthur_client.api_bindings.models.gcp_agent_metadata_response.GCPAgentMetadataResponse(
                            project_id = '', 
                            region = '', 
                            resource_id = '', ), ), 
                    rules = [
                        arthur_client.api_bindings.models.rule_response.RuleResponse(
                            id = '', 
                            name = '', 
                            type = 'KeywordRule', 
                            apply_to_prompt = True, 
                            apply_to_response = True, 
                            enabled = True, 
                            scope = 'default', 
                            created_at = 56, 
                            updated_at = 56, 
                            config = null, )
                        ], 
                    metrics = [
                        arthur_client.api_bindings.models.metric_response.MetricResponse(
                            id = '', 
                            name = '', 
                            type = 'QueryRelevance', 
                            metric_metadata = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            enabled = True, )
                        ], ),
        )
        """

    def testPutTaskStateCacheRequest(self):
        """Test PutTaskStateCacheRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
